==> haskell-network-multicast-0.2.0-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-2GIB7j8myqYEfw6UM3yF7v
key: network-multicast-0.2.0-2GIB7j8myqYEfw6UM3yF7v
license: LicenseRef-PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
author: Audrey Tang <audreyt@audreyt.org>
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
abi: 4ae22ecb0986c248353fd47ccf70fde1
exposed: True
exposed-modules:
    Network.Multicast
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-2GIB7j8myqYEfw6UM3yF7v
depends:
    base-4.11.1.0 network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.2.0-37-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-3WYeSoReCg88owwd1UyHe9
key: network-multicast-0.2.0-3WYeSoReCg88owwd1UyHe9
license: LicenseRef-PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
author: Audrey Tang <audreyt@audreyt.org>
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
abi: 7a8c2a2e2627bca7cbd111708eaf4a5b
exposed: True
exposed-modules:
    Network.Multicast
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-3WYeSoReCg88owwd1UyHe9
depends:
    base-4.11.1.0 network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
